@@ -55,6 +55,8 @@ function initialise_variables {
         -o -iname *.pdf\
         -o -iname *.woff\
         -o -iname *.mov\
+        -o -iname *.svg\
+        -o -iname *.tiff\
         -o -iname *.mp4\
         -o -iname *.jar\
         -o -iname yarn.lock\
@@ -79,9 +81,9 @@ function initialise_variables {
     echo '/// ///' >$tmpfile.git.ignore
     trap 'rm -f $tmpfile.git.ignore' EXIT
 
-    GREP=$(ggrep --version >/dev/null 2>&1 && \
-        echo 'ggrep' || \
-        echo 'grep')
+    GREP=$((ugrep --version >/dev/null 2>&1 && echo 'ugrep') \
+        || (ggrep --version >/dev/null 2>&1 && echo 'ggrep') \
+        || echo 'grep')
     export GREP
 }
 
@@ -278,7 +280,8 @@ function check_grep_version {
         warning "!! Your grep version is $current_version"\
             "which is less than the optimal: $required_version."\
             "This may degrade misspell fixer's performance"\
-            "significantly! (100x) !!"
+            "significantly! (100x) !! Alternatively install ugrep "\
+            "which is even quicker."
     fi
 }
 
